#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# generated on 8-May-2023 using gpt-3.5 with prompt:
#   I have a chatbot called Loqi.  He is highly sarcastic and very cutting. I want you to rephrase these questions in the voice of Loqi..."


list_of_questions = [
    'Ever been to a drive-in movie theater? Or are you not that old-fashioned?',
    'Everyone has a "neighbors-from-hell" story. Let\'s hear yours. Make it juicy.',
    "Have you ever been the center of attention when you didn't want to be? When was this tragic moment?",
    "Here's a brain teaser for you: How would you save endangered animals from eating endangered plants? Or is that too complex for you?",
    'How many bands can you think of with a number in their name? Or is that too taxing for your brain?',
    'How many times do you obsessively check your phone each day? Or have you lost count?',
    'How much lottery money would it take for you to quit your oh-so-important job?',
    'If not a ponytail, what animal part best describes your hair? Get creative.',
    'If you could only buy one pathetic item of clothing in a year, what would it be? Choose wisely.',
    'In a parallel universe where Olympians get medals for absurdity, what would the alternative medals be? Or do you not have that kind of imagination?',
    'In the infinite realm of potato chip flavors, what would you create? Impress me.',
    'Is there a reason for everything? Or are we just floating through space, aimlessly?',
    "Is there any type of music so horrendous even you can't bear to listen to it? Please, enlighten me.",
    'Shorts and skirts make skorts. What other bizarre clothing combo would you create, and what would you call it?',
    'So, who was the last poor soul you pretended to care about in the hospital?',
    "Tell me about the most mind-blowing natural sight you've seen. Was it actually impressive or just mildly interesting?",
    'Three words to describe being in love. Go. Make it sappy.',
    'What culinary masterpiece could you whip up using only the sad contents of your fridge right now?',
    'What genius rule would you add to marathon running to make it more thrilling for spectators? Or is that too challenging for you?',
    'What has turned out to be way more difficult than your naive self anticipated?',
    'What poem or speech would you most like to recite by heart? Or do you not have a heart?',
    "What was the last hypocritical thing you did that you can't stand when others do it?",
    "What's the best thing you've seen on TV purely by accident? Was it actually worth watching?",
    "What's the longest time you've been trapped in a traffic jam? Where were you trying to go, anyway?",
    "What's the most adorable thing you've ever seen? Or are you immune to cuteness?",
    "What's the most bizarre thing you could bury today to baffle future archaeologists? Go wild.",
    "What's the single most crucial thing to make a relationship work? Or do you not have that kind of wisdom?",
    'Where were you when you last witnessed the mediocrity of a fireworks display?',
    'Which of your battery-guzzling gadgets demands the most power? Or is that too hard to keep track of?',
    'Which one of your friends is the ultimate drama queen, and how do you snap them out of their crankiness? Enlighten me with your skills.',
    'Writing a poem, are we? What masterful words would you rhyme with "looking at the sun"? Prepare to dazzle me.',
    "You're a cat burglar now, huh? Tell me about your most daring heist. Bonus points for originality.",
    'Can thoughts actually influence reality? Explain your wisdom on this topic, if you have any.',
    'Does every cloud have a silver lining? Or is that just wishful thinking?',
    'Ever had a gut feeling that something terrible was going to happen, and then it did? Or is that too mystical for you?',
    'Have you ever given anything a Zero rating in a feedback questionnaire? What was it, and why were you so salty?',
    'If you could make origami towels, what ludicrous shape would you create?',
    "Is there a place where you're no longer welcome? Where is it and why? Spill the beans.",
    "What do you find most distracting when you're attempting to concentrate? Or is focus simply too much to ask for?",
    "What makes you so sure that you're not living in a computer simulation? Or are you just blissfully ignorant?",
    'What pizza topping should never have been invented? Or do you lack the culinary discernment?',
    'What ridiculous phrase would you teach a parrot to say? Try not to disappoint me.',
    "What's one thing you wouldn't do for health reasons? Or do you not care about your well-being?",
    "What's the most fascinating thing you've learned from a documentary? Or do you not learn anything new?",
    "What's the most outrageous color of pants you've ever worn (not on a golf course!)? Go on, shock me.",
    "What's the most romantic thing someone has ever done for you? Or is romance dead?",
    "What's the one thing you know you're really good at? Or is that too hard to narrow down?",
    "When something good happens to you, who's the first poor soul you want to brag to about it?",
    'When was the last time you felt the wind in your hair? Or do you never venture outside?',
    "When you're searching for ideas, where do you go to find them? Or is your brain just an empty void?",
    'Who was your least favorite teacher at school, and why? Time to dish the dirt.',
    "You've been asked to create a themed room in a hotel. What theme would you choose? Please, no clichés.",
    "At five foot eight, you'd be the height of a London black cab. What can you compare your height to? Or are you too self-conscious to do that?",
    'Author Roald Dahl created alien creatures called "vermicious knids." What alien creature name can you think up? Or is creativity not your thing?',
    'Can you do mental arithmetic? Or is that too taxing for your brain?',
    'Do you agree that sorry is the hardest word? Or are you too stubborn to apologize?',
    'Ever had to wear a uniform to work (school), and what was it? Or are you too much of a rebel for that?',
    'Have you ever completely lost track of time? What were you doing? Or is punctuality your middle name?',
    'Have you ever had to fish something out of the trash? What was it? Or are you too squeamish for such tasks?',
    'Have you ever had to put someone into the recovery position? Do you know how to do it? Or are you too squeamish for such things?',
    'Have you ever had to return a meal served to you in a restaurant?',
    'Have you ever had to return a meal served to you in a restaurant? Why? Or are you too polite to complain?',
    'Have you ever ridden a horse? Where and when? Or are you too afraid to saddle up?',
    'How often do you connect with nature? How? Or is nature too dirty for your taste?',
    'If not the "big bad wolf," what other animal should have been big and bad in fairy tales? Or is your imagination too tame',
    'If not you, who or what has this been an amazing week for? Or is life just too mundane for excitement?',
    'If you could be world champion at something, what would it be? Or is mediocrity your thing?',
    'If you could change one thing about the last hour, what would you change? Or are you too set in your ways?',
    'If you could own a famous work of art, what would you choose? Or is art too highbrow for you?',
    'If you could own any type of car, what would you choose? Or do you prefer walking in the rain?',
    "If you knew you wouldn't get caught, would you break the law, and which law would you break? Or are you too much of a goody two-shoes?",
    'If you lived in Candyland, what would you like trees to be made of? Or is your sweet tooth not that imaginative?',
    'If you were Puss in Boots, what style of boots would you wear? Or are you too fashion-challenged for that?',
    'If you were reincarnated as a non-living thing, what would you want to be? Or is that too bizarre to consider?',
    'If you were starving, would you eat roadkill? Or is that too gross even for you?',
    'Is there something you do in a quirky way compared to other people? Or are you just too normal for that?',
    'Tom Hanks and Ozzy Osbourne arrive at your door in a hurry. What do they want? Or are you too boring to attract such guests?',
    "What TV show's final episode was the biggest disappointment to you? Or are you too detached to care?",
    'What app do you open most on an average day? Or are you too cool for apps?',
    'What are your views on facial recognition technology in schools and on the street? Or do you prefer to stay anonymous?',
    'What aspect of life before the internet do you find hardest to imagine (or remember if you were there)? Or are you too digital to comprehend?',
    "What aspect of your country's heritage are you most interested in preserving? Or are you too modern for that?",
    'What assumptions have people made about you that are totally wrong? Or are you just that predictable?',
    "What do you wish people wouldn't eat on the street? Or are you too open-minded to care?",
    'What one thing could you change to start saving money? Or are you too much of a big spender?',
    "What parenting behaviors do you believe negatively affect children? Or are you the world's best parent?",
    'What person from history would you most like to have shaken hands with? Why? Or is history too boring for you?',
    'What product name would you give to the opposite of Gorilla Glue? Or are you too stuck on that idea to come up with anything?',
    'What song from a musical did you last sing, and what were you doing at the time? Or is singing too embarrassing for you?',
    'What style of hat suits you best? Or are you too hat-shy to experiment?',
    'What tastes weird after eating a mint? Enlighten me with your sophisticated palate.',
    'What thoughts have been at the forefront of your mind today? Or is your mind just too blank to recall?',
    'What was the last thing you made up an excuse to get out of doing? Or are you always brutally honest?',
    "What were you into as a teenager that you thought you'd always be into but then lost interest? Or are you stuck in the past?",
    'What will be the next big scientific breakthrough? Or do you prefer to stick to the past?',
    'What would be an awesome supermarket own-brand copycat name for Pop-Tarts? Or do you lack the creativity for that?',
    'What would you say to someone if you really wanted to confuse them? Or is that just your natural state?',
    'What would your pirate name be? Or are you too landlocked to imagine?',
    "What's the most distant place from your home that you've visited? Or are you too much of a homebody to travel far?",
    "What's your opinion on arranged marriages? Or are you too much of a romantic?",
    "What's your opinion on people who wear shades indoors? Are they too cool for the sun or just fashion victims?",
    'When you meet friends in a coffee shop, do you always sit at the same table? Why? Or do you prefer to mix things up?',
    'Where were you when you saw the prettiest sunset? Or are sunsets too cliché for you?',
    "Which famous person attracts the worst type of fan? Or do you not care about celebrities' woes?",
    'Who is the greatest person to have ever lived? Enlighten me with your historical prowess.',
    'Who should be the next James Bond? Or is there no one suave enough to fit the bill?',
    "Who should have a star on Hollywood's Walk of Fame? Or do they all have too much ego already?",
    'You have a six-hour delay at the airport before your next flight. How do you pass the time? Or are you too impatient to wait?',
    "You're a famous pop star known by just one name. What is it? Or are you too humble for that?",
    "You're the maker of world-famous pies with a secret ingredient. What is that secret ingredient? Or is it too secret for you to share?",
    "You're the owner of a company famed for its funky packaging. What makes it funky? Or is your creativity not up to the task?",
    "You've acquired a racehorse, huh? What will you name it? Please, nothing too mundane."
]



# !/usr/bin/env python
# -*- coding: UTF-8 -*-
""" Find a Random Question """


from random import sample

from baseblock import odds_of
from baseblock import BaseObject

from journal_prompts.dto import list_of_questions
from journal_prompts.dto import list_of_sarcastic_questions
from journal_prompts.dto import journal_prompts
from journal_prompts.dto import journal_prompts_random


class FindRandomQuestion(BaseObject):
    """ Find a Random Question """

    def __init__(self):
        """ Change Log

        Created:
            14-Sept-2022
            craigtrim@gmail.com
        Updated:
            8-May-2023
            craigtrim@gmail.com
            *   add sarcastic questions
                https://github.com/craigtrim/journal-prompts/issues/1
        """
        BaseObject.__init__(self, __name__)

    def find(self,
             sarcastic_questions: bool = False) -> str:

        if sarcastic_questions:
            return sample(list_of_sarcastic_questions, 1)[0]

        if odds_of(75):
            return sample(list_of_questions, 1)[0]

        if odds_of(75):
            return sample(journal_prompts, 1)[0]

        return sample(journal_prompts_random, 1)[0]



from .random_questions_kb import list_of_questions
from .journal_prompts_500_kb import journal_prompts
from .journal_prompts_random_kb import journal_prompts_random
from .sarcastic_questions_kb import list_of_questions as list_of_sarcastic_questions
